package test.cdi.beans_k;

public interface Bar {}
